package com.xinelu.manage.mapper.crowdinfo;

import com.xinelu.manage.domain.crowdinfo.CrowdInfo;
import java.util.List;


/**
 * 人群信息Mapper接口
 *
 * @author xinelu
 * @date 2024-03-04
 */
public interface CrowdInfoMapper {
    /**
     * 查询人群信息
     *
     * @param id 人群信息主键
     * @return 人群信息
     */
    public CrowdInfo selectCrowdInfoById(Long id);

    /**
     * 查询人群信息列表
     *
     * @param crowdInfo 人群信息
     * @return 人群信息集合
     */
    public List<CrowdInfo> selectCrowdInfoList(CrowdInfo crowdInfo);

    /**
     * 新增人群信息
     *
     * @param crowdInfo 人群信息
     * @return 结果
     */
    public int insertCrowdInfo(CrowdInfo crowdInfo);

    /**
     * 修改人群信息
     *
     * @param crowdInfo 人群信息
     * @return 结果
     */
    public int updateCrowdInfo(CrowdInfo crowdInfo);

    /**
     * 删除人群信息
     *
     * @param id 人群信息主键
     * @return 结果
     */
    public int deleteCrowdInfoById(Long id);

    /**
     * 批量删除人群信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCrowdInfoByIds(Long[] ids);
}
